==> ssp-center-api-0.1.16-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/SlotStatisticsDataRsp.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;


import java.io.Serializable;

import org.apache.commons.lang3.builder.ToStringBuilder;

/**
 * ClassName:SlotStatisticsDataRsp <br/>
 * Function: 广告位数据统计 <br/>
 * Date: 2016年12月21日 下午2:09:30 <br/>
 *
 * @author ZFZ
 * @version
 * @since JDK 1.6
 * @see
 */
public class SlotStatisticsDataRsp extends BaseStatisticsDataRsp implements Serializable {

    /**
     * @since JDK 1.6
     */
    private static final long serialVersionUID = -6256880268510342548L;

    /** 广告位ID */
    private Long              slotId;

    /** 广告位名称 */
    private String            slotName;

    /** 广告位类型 */
    private Integer           slotType;

    /** appName */
    private String            appName;

    /** 媒体ID */
    private Long              appId;

    /**系统平台*/
    private String           platform;

    /** 规格名称 */
    private String            msName;

    /** 当前日期 */
    private String            curDate;

    /** 用户ID */
     private Long             mediaId;

     /** 用户账号 */
     private String           account;

    /**
     * appId.
     *
     * @return the appId
     * @since JDK 1.6
     */
    public Long getAppId() {
        return appId;
    }

    /**
     * appId.
     *
     * @param appId the appId to set
     * @since JDK 1.6
     */
    public void setAppId(Long appId) {
        this.appId = appId;
    }

    /**
     * slotId.
     *
     * @return the slotId
     * @since JDK 1.6
     */
    public Long getSlotId() {
        return slotId;
    }

    /**
     * slotId.
     *
     * @param slotId the slotId to set
     * @since JDK 1.6
     */
    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    /**
     * slotName.
     *
     * @return the slotName
     * @since JDK 1.6
     */
    public String getSlotName() {
        return slotName;
    }

    /**
     * slotName.
     *
     * @param slotName the slotName to set
     * @since JDK 1.6
     */
    public void setSlotName(String slotName) {
        this.slotName = slotName;
    }

    /**
     * slotType.
     *
     * @return the slotType
     * @since JDK 1.6
     */
    public Integer getSlotType() {
        return slotType;
    }

    /**
     * slotType.
     *
     * @param slotType the slotType to set
     * @since JDK 1.6
     */
    public void setSlotType(Integer slotType) {
        this.slotType = slotType;
    }

    /**
     * appName.
     *
     * @return the appName
     * @since JDK 1.6
     */
    public String getAppName() {
        return appName;
    }

    /**
     * appName.
     *
     * @param appName the appName to set
     * @since JDK 1.6
     */
    public void setAppName(String appName) {
        this.appName = appName;
    }


    /**
     * msName.
     *
     * @return the msName
     * @since JDK 1.6
     */
    public String getMsName() {
        return msName;
    }

    /**
     * msName.
     *
     * @param msName the msName to set
     * @since JDK 1.6
     */
    public void setMsName(String msName) {
        this.msName = msName;
    }

    /**
     * platform.
     *
     * @return the platform
     * @since JDK 1.6
     */
    public String getPlatform() {
        return platform;
    }

    /**
     * platform.
     *
     * @param platform the platform to set
     * @since JDK 1.6
     */
    public void setPlatform(String platform) {
        this.platform = platform;
    }

    /**
     * curDate.
     *
     * @return the curDate
     * @since JDK 1.6
     */
    public String getCurDate() {
        return curDate;
    }

    /**
     * curDate.
     *
     * @param curDate the curDate to set
     * @since JDK 1.6
     */
    public void setCurDate(String curDate) {
        this.curDate = curDate;
    }

    public Long getMediaId() {
        return mediaId;
    }

    public void setMediaId(Long mediaId) {
        this.mediaId = mediaId;
    }

    public String getAccount() {
        return account;
    }

    public void setAccount(String account) {
        this.account = account;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }



}

==> ssp-center-api-0.1.24-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/SlotStatisticsDataRsp.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;


import java.io.Serializable;

import org.apache.commons.lang3.builder.ToStringBuilder;

/**
 * ClassName:SlotStatisticsDataRsp <br/>
 * Function: 广告位数据统计 <br/>
 * Date: 2016年12月21日 下午2:09:30 <br/>
 *
 * @author ZFZ
 * @version
 * @since JDK 1.6
 * @see
 */
public class SlotStatisticsDataRsp extends BaseStatisticsDataRsp implements Serializable {

    /**
     * @since JDK 1.6
     */
    private static final long serialVersionUID = -6256880268510342548L;

    /** 广告位ID */
    private Long              slotId;

    /** 广告位名称 */
    private String            slotName;

    /** appName */
    private String            appName;

    /** 媒体ID */
    private Long              appId;

    /**系统平台*/
    private String           platform;

    /** 规格名称 */
    private String            msName;

    /** 当前日期 */
    private String            curDate;

    /** 用户ID */
     private Long             mediaId;

     /** 用户账号 */
     private String           account;
     
     /** 一级标签 */
     private String            tagName1;
     /** 二级标签 */
     private String            tagName2;

    /**
     * appId.
     *
     * @return the appId
     * @since JDK 1.6
     */
    public Long getAppId() {
        return appId;
    }

    /**
     * appId.
     *
     * @param appId the appId to set
     * @since JDK 1.6
     */
    public void setAppId(Long appId) {
        this.appId = appId;
    }

    /**
     * slotId.
     *
     * @return the slotId
     * @since JDK 1.6
     */
    public Long getSlotId() {
        return slotId;
    }

    /**
     * slotId.
     *
     * @param slotId the slotId to set
     * @since JDK 1.6
     */
    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    /**
     * slotName.
     *
     * @return the slotName
     * @since JDK 1.6
     */
    public String getSlotName() {
        return slotName;
    }

    /**
     * slotName.
     *
     * @param slotName the slotName to set
     * @since JDK 1.6
     */
    public void setSlotName(String slotName) {
        this.slotName = slotName;
    }

    /**
     * appName.
     *
     * @return the appName
     * @since JDK 1.6
     */
    public String getAppName() {
        return appName;
    }

    /**
     * appName.
     *
     * @param appName the appName to set
     * @since JDK 1.6
     */
    public void setAppName(String appName) {
        this.appName = appName;
    }


    /**
     * msName.
     *
     * @return the msName
     * @since JDK 1.6
     */
    public String getMsName() {
        return msName;
    }

    /**
     * msName.
     *
     * @param msName the msName to set
     * @since JDK 1.6
     */
    public void setMsName(String msName) {
        this.msName = msName;
    }

    /**
     * platform.
     *
     * @return the platform
     * @since JDK 1.6
     */
    public String getPlatform() {
        return platform;
    }

    /**
     * platform.
     *
     * @param platform the platform to set
     * @since JDK 1.6
     */
    public void setPlatform(String platform) {
        this.platform = platform;
    }

    /**
     * curDate.
     *
     * @return the curDate
     * @since JDK 1.6
     */
    public String getCurDate() {
        return curDate;
    }

    /**
     * curDate.
     *
     * @param curDate the curDate to set
     * @since JDK 1.6
     */
    public void setCurDate(String curDate) {
        this.curDate = curDate;
    }

    public Long getMediaId() {
        return mediaId;
    }

    public void setMediaId(Long mediaId) {
        this.mediaId = mediaId;
    }

    public String getAccount() {
        return account;
    }

    public void setAccount(String account) {
        this.account = account;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

	public String getTagName1() {
		return tagName1;
	}

	public void setTagName1(String tagName1) {
		this.tagName1 = tagName1;
	}

	public String getTagName2() {
		return tagName2;
	}

	public void setTagName2(String tagName2) {
		this.tagName2 = tagName2;
	}



}
